@@ -7,7 +7,7 @@ This example shows how to make a basic box plot using US Population data from 20
 import altair as alt
 from vega_datasets import data
 
-source = data.population()
+source = data.population.url
 
 base = alt.Chart(source)
 
@@ -19,7 +19,7 @@ upper_whisker = 'max(people):Q'
 
 # Compose each layer individually
 lower_plot = base.mark_rule().encode(
-    y=alt.Y(lower_whisker, axis=alt.Axis(title="population")),
+    y=alt.Y(lower_whisker, title="population"),
     y2=lower_box,
     x='age:O'
 )
