@@ -21,7 +21,7 @@ line = base.mark_line().encode(
 # Configure the confidence interval
 confidence_interval = base.mark_area(opacity=0.3).encode(
     x='Year',
-    y=alt.Y('ci0(Miles_per_Gallon)', axis=alt.Axis(title='Miles/Gallon')),
+    y=alt.Y('ci0(Miles_per_Gallon)', title='Miles/Gallon'),
     y2='ci1(Miles_per_Gallon)'
 )
 
