@@ -18,7 +18,7 @@ slider = alt.binding_range(min=1900, max=2000, step=10)
 select_year = alt.selection_single(name="year", fields=['year'], bind=slider)
 
 alt.Chart(source).mark_bar().encode(
-    x=alt.X('sex:N', axis=alt.Axis(title=None)),
+    x=alt.X('sex:N', title=None),
     y=alt.Y('people:Q', scale=alt.Scale(domain=(0, 12000000))),
     color=alt.Color('sex:N', scale=pink_blue),
     column='age:O'
