@@ -15,8 +15,12 @@ import numpy as np
 
 try:
     from pandas.api.types import infer_dtype
-except ImportError: # Pandas before 0.20.0
+    # keywords required; see https://github.com/altair-viz/altair/issues/1314
+    _infer_dtype_kwds = {'skipna': False}
+except ImportError:
+    # This is the appropriate import for pandas < 0.20.0
     from pandas.lib import infer_dtype
+    _infer_dtype_kwds = {}  # no keywords allowed in pandas < 0.20
 
 from .schemapi import SchemaBase, Undefined
 
@@ -69,7 +73,7 @@ def infer_vegalite_type(data):
     data: Numpy array or Pandas Series
     """
     # Otherwise, infer based on the dtype of the input
-    typ = infer_dtype(data)
+    typ = infer_dtype(data, **_infer_dtype_kwds)
 
     # TODO: Once this returns 'O', please update test_select_x and test_select_y in test_api.py
 
@@ -304,16 +308,18 @@ def use_signature(Obj):
         f._uses_signature = Obj
 
         # Supplement the docstring of f with information from Obj
-        doclines = Obj.__doc__.splitlines()
-        if f.__doc__:
-            doc = f.__doc__ + '\n'.join(doclines[1:])
-        else:
-            doc = '\n'.join(doclines)
-        try:
-            f.__doc__ = doc
-        except AttributeError:
-            # __doc__ is not modifiable for classes in Python < 3.3
-            pass
+        if Obj.__doc__:
+            doclines = Obj.__doc__.splitlines()
+            if f.__doc__:
+                doc = f.__doc__ + '\n'.join(doclines[1:])
+            else:
+                doc = '\n'.join(doclines)
+            try:
+                f.__doc__ = doc
+            except AttributeError:
+                # __doc__ is not modifiable for classes in Python < 3.3
+                pass
+        
         return f
     return decorate
 
